# court-scraper

A Python library that downloads case information from U.S. county courts

## Documentation

```{toctree}
:glob:
:maxdepth: 1

install
usage
contributing
writing_a_scraper
site-discovery
testing
releasing
```

## Links

- Gitter for chat: [gitter.im/court-scraper/general](https://gitter.im/court-scraper/general)
- Documentation: [court-scraper.readthedocs.io](https://court-scraper.readthedocs.io/en/latest/)
- GitHub: [github.com/biglocalnews/court-scraper](https://github.com/biglocalnews/court-scraper)
- PyPI: [pypi.org/project/court-scraper/](https://pypi.org/project/court-scraper/)
